@@ -4,12 +4,13 @@ try:
 except ImportError:
     import re
 
-
+flags = re.S | re.I
 PLACEHOLDER = '<@!hmin_placeholder_%s_!@>'
 RE_REPLACED_TAG = re.compile(
-    ur'(<(script|textarea|style|pre).*?>.*?</(script|textarea|style|pre)>)', re.S
+    ur'(<(script|textarea|style|pre).*?>.*?</(script|textarea|style|pre)>)',
+    flags
 )
-RE_COMMENTS = re.compile(ur'<!--(?!\[if.*?\]).*?-->', re.S | re.I)
+RE_COMMENTS = re.compile(ur'<!--(?!\[if.*?\]).*?-->', flags)
 RE_PLACEHOLDER = re.compile(
     ur'%s' % PLACEHOLDER.replace('%s', '([0-9]+)')
 )
@@ -25,7 +26,10 @@ def minify(content, remove_comments=True):
         return safe_storage[int(m.group(1))]
 
     # decode unicode
-    content = content.decode('UTF-8', 'strict')
+    try:
+        content = content.decode('utf8')
+    except (UnicodeDecodeError, UnicodeEncodeError):
+        pass
 
     # replace dangerous tags with placeholders
     safe_storage = dict()
